@@ -497,16 +497,23 @@ object or the name of the stage.
 		my $self = shift;
 		my $stages = $self->_stages;
 		return
-		    map  { $self->_croak( "Unknown stage name ($_) passed to add_deps" ) 
+		    map  { $self->_croak( "Unknown stage name ($_) passed to add_deps" )
 			           unless exists $stages->{$_};
 				   $_
 				 }
 			grep { defined }
 			map  { ref($_) ? $_->name : $_ }
+			map  { ref($_) eq 'Regexp' ? ($self->_match_stages( $_ )) : ($_) }
 			map  { ref($_) eq 'ARRAY' ? @{$_} : ($_) }
 			@_
 	}
 
+	sub _match_stages {
+		my $self = shift;
+		my $pat  = shift;
+		return grep { m/$pat/ } keys %{ $self->_stages };
+	}
+
 	method _add_dep => sub { # little cost/no damage if called again with same dep and pre_req
 		my ( $self, $pre_req, $dep ) = @_;
 		return if $self->_deps->{$pre_req}{$dep};
